@@ -13,7 +13,7 @@ from itertools import repeat, chain
 from pathlib import Path
 from queue import Queue
 from threading import Thread, Lock, current_thread
-from typing import Optional, Dict, List, Any, cast, Union, Iterable, DefaultDict, Tuple, Set
+from typing import Optional, Dict, List, Any, cast, Union, Iterable, DefaultDict, Tuple
 from urllib.parse import urlparse
 
 from requests import Session, Response
@@ -23,7 +23,7 @@ from requests.exceptions import InvalidSchema
 from isisdl.backend.crypt import get_credentials
 from isisdl.backend.status import StatusOptions, DownloadStatus, RequestHelperStatus
 from isisdl.settings import download_timeout, download_timeout_multiplier, download_static_sleep_time, num_tries_download, status_time, perc_diff_for_checksum, error_text, bandwidth_mavg_perc, \
-    extern_ignore, log_file_location, datetime_str
+    extern_ignore, log_file_location, datetime_str, regex_is_isis_document
 from isisdl.settings import enable_multithread, discover_num_threads, is_windows, is_macos, is_testing, testing_bad_urls, url_finder, isis_ignore
 from isisdl.utils import User, path, sanitize_name, args, on_kill, database_helper, config, generate_error_message, logger, parse_google_drive_url, get_url_from_gdrive_confirmation, \
     DownloadThrottler, MediaType, HumanBytes, normalize_url
@@ -79,6 +79,7 @@ class SessionWithKey(Session):
 
             key = _key[0]
 
+            token = ""
             try:
                 # This is a somewhat dirty hack.
                 # The Moodle API always wants to have a token. This is obtained through the `/login/token.php` site.
@@ -91,11 +92,24 @@ class SessionWithKey(Session):
 
                 # Note: Don't replace .get by .get_ - Since the .get_ will catch all exceptions.
 
-                s.get("https://isis.tu-berlin.de/admin/tool/mobile/launch.php?service=moodle_mobile_app&passport=12345&urlscheme=moodledownloader")
+                os.environ['no_proxy'] = '*'
+
+                s.get(
+                    "https://isis.tu-berlin.de/admin/tool/mobile/launch.php",
+                    params={"service": "moodle_mobile_app", "passport": "12345", "urlscheme": "moodledownloader"}
+                )
+
                 raise InvalidSchema
+
             except InvalidSchema as ex:
                 token = standard_b64decode(str(ex).split("token=")[-1]).decode().split(":::")[1]
 
+            finally:
+                try:
+                    del os.environ['no_proxy']
+                except Exception:
+                    pass
+
             s.key = key
             s.token = token
 
@@ -383,6 +397,7 @@ class MediaContainer:
 
     @property
     def should_download(self) -> bool:
+        # raise ValueError
         if self._done or self.media_type == MediaType.corrupted:
             return False
 
@@ -392,6 +407,7 @@ class MediaContainer:
             actual_size = self.path.stat().st_size
 
         maybe_container = MediaContainer.from_dump(self.url, self.course)
+
         if isinstance(maybe_container, bool):
             return maybe_container
 
@@ -652,7 +668,7 @@ class Course:
 
             parse = urlparse(link)
             if parse.scheme and parse.netloc and extern_ignore.match(link) is None and isis_ignore.match(link) is None:
-                all_content.append(PreMediaContainer(link, self, MediaType.extern, None))
+                all_content.append(PreMediaContainer(link, self, MediaType.document if regex_is_isis_document.match(link) is not None else MediaType.extern, None))
                 _links.append(link)
 
         return all_content
@@ -929,6 +945,7 @@ class RequestHelper:
 
 
 def check_for_conflicts_in_files(files: List[MediaContainer]) -> List[MediaContainer]:
+    # TODO: Check for case insensitive filesystem and implement the fix here
     final_list: List[MediaContainer] = []
     new_files: List[MediaContainer] = []
 
@@ -992,19 +1009,17 @@ def check_for_conflicts_in_files(files: List[MediaContainer]) -> List[MediaConta
     for file in {file.path: file for file in files}.values():
         hard_link_conflicts[file.download_url].append(file)
 
-    conflict_urls: Set[str] = set()
-
     for conflict in hard_link_conflicts.values():
         if len(conflict) > 1:
             conflict.sort(key=lambda x: x.time)
             conflict[0]._links.extend(conflict[1:])
-            conflict_urls.add(conflict[0].url)
+            # conflict_urls.add(conflict[0].url)
             final_list.append(conflict[0])
 
         else:
             final_list.append(conflict[0])
 
-    return [file for file in final_list if file.url not in conflict_urls]
+    return final_list
 
 
 class Downloader(Thread):
@@ -1089,6 +1104,9 @@ class CourseDownloader:
                 else:
                     for con in container._links:
                         if con.should_download:
+                            if not container.path.exists():
+                                container.path.open("w").close()
+
                             con.hardlink(container)
 
         CourseDownloader.containers = containers
