@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import enum
-import math
 import shutil
 import time
 from datetime import datetime, timedelta
@@ -102,9 +101,9 @@ class Status(Thread):
     def generate_log_message(self) -> List[str]:
         return []
 
-    def add(self, *args: Any, **kwargs: Any) -> None:
-        # self.count += 1
-        ...
+    def add(self, num: int) -> None:
+        if self.count is not None:
+            self.count += num
 
     def done(self, *args: Any, **kwargs: Any) -> None:
         if self.count is not None:
@@ -269,22 +268,27 @@ class DownloadStatus(Status):
             log_strings.append("")
 
             # Now determine the already downloaded amount and display it
-            thread_format = math.ceil(math.log10(len(self.thread_files) or 1))
+            # thread_format = math.ceil(math.log10(len(self.thread_files) or 1))
+            course_format = max(len(str(item.course)) if item is not None else 1 for item in self.thread_files.values())
             for thread_id, container in self.thread_files.items():
-                thread_string = f"Thread {thread_id:{' '}<{thread_format}}"
                 if container is None:
-                    log_strings.append(thread_string)
+                    log_strings.append("")
                     continue
 
                 log_strings.append(
-                    f"{thread_string} {self.progress_bar_container(container)} [ {HumanBytes.format_pad(container.current_size)} | {HumanBytes.format_pad(container.size)} ] - {container}")
+                    f"{self.progress_bar_container(container)} "
+                    f"[ {HumanBytes.format_pad(container.current_size)} | {HumanBytes.format_pad(container.size)} ]"
+                    f" {str(container.course):{' '}<{course_format}}"
+                    f" - {container}")
                 pass
 
             # Optional streaming info
             if self.stream_file is not None:
                 log_strings.append("")
                 log_strings.append(
-                    f"Stream:  {self.progress_bar_container(self.stream_file)} [ {HumanBytes.format_pad(self.stream_file.current_size)} | {HumanBytes.format_pad(self.stream_file.size)} ]"
+                    f"Stream:  {self.progress_bar_container(self.stream_file)} "
+                    f"[ {HumanBytes.format_pad(self.stream_file.current_size)} | {HumanBytes.format_pad(self.stream_file.size)} ]"
+                    f" {str(self.stream_file.course)}"
                     f" - {self.stream_file}")
             else:
                 log_strings.extend(["", ""])
