@@ -610,7 +610,7 @@ def print_changelog_for_version(new_version: Union[LegacyVersion, Version]) -> N
     assert not isinstance(new_version, LegacyVersion)
 
     for i in range(current_version.micro + 1, new_version.micro + 1):
-        con = requests.get(f"https://raw.githubusercontent.com/Emily3403/isisdl/main/src/isisdl/changelog/"
+        con = requests.get(f"https://raw.githubusercontent.com/Emily3403/isisdl/main/src/isisdl/resources/changelog/"
                            f"{new_version.major}.{new_version.minor}/{new_version.major}.{new_version.minor}.{new_version.micro}.md")
         print(con.text)
 
@@ -1360,7 +1360,7 @@ class DownloadThrottler(Thread):
         return int((self.download_rate * 1024 ** 2) // download_chunk_size * self.refresh_rate) or 1
 
 
-# TODO: Add link type and store that in the database + reference to checksum?<
+# TODO: Add link type and store that in the database + reference to checksum?
 class MediaType(enum.Enum):
     document = 1
     extern = 2
